@@ -1,5 +1,5 @@
 POSIXtime2iso8601 = function(x,tz){
   POStime = as.POSIXlt(x,tz) #turn to right timezone
-  POStime_z = chartime2iso8601(as.character(POStime),tz) #change format
+  POStime_z = chartime2iso8601(format(POStime),tz) #change format
   return(POStime_z)
 }
\ No newline at end of file
