@@ -91,7 +91,8 @@ g.calibrate = function(datafile, params_rawdata = c(),
   options(warn = -1) #turn off warnings
   suppressWarnings(expr = {decn = g.dotorcomma(datafile, dformat, mon, 
                                                desiredtz = params_general[["desiredtz"]],
-                                               rmc.dec = params_rawdata[["rmc.dec"]])}) #detect dot or comma dataformat
+                                               rmc.dec = params_rawdata[["rmc.dec"]],
+                                               loadGENEActiv = params_rawdata[["loadGENEActiv"]])}) #detect dot or comma dataformat
   options(warn = 0) #turn on warnings
   #creating matrixes for storing output
   S = matrix(0,0,4) #dummy variable needed to cope with head-tailing succeeding blocks of data
@@ -141,6 +142,7 @@ g.calibrate = function(datafile, params_rawdata = c(),
     if (length(P) > 0) { #would have been set to zero if file was corrupt or empty
       if (mon == 1) {
         data = P$rawxyz / 1000 #convert g output to mg for genea
+        data = as.matrix(data, rownames.force = FALSE)
       } else if (mon == 4 & dformat == 3) {
         data = P$rawxyz #change scalling for Axivity?
       } else if (mon == 2 & dformat == 1) {
@@ -166,11 +168,13 @@ g.calibrate = function(datafile, params_rawdata = c(),
       if (min(dim(S)) > 1) {
         data = rbind(S,data)
       }
-      # remove 0s if ActiGraph csv (idle sleep mode)
-      if (mon == 3 & dformat == 2) {
+      # remove 0s if ActiGraph csv (idle sleep mode) OR if similar imputation done in ad-hoc csv
+      # current ActiGraph csv's are not wiht zeros but with last observation carried forward
+      zeros = which(data[,1] == 0 & data[,2] == 0 & data[,3] == 0)
+      if ((mon == 3 & dformat == 2) | length(zeros) > 0) {
         data = g.imputeTimegaps(x = as.data.frame(data), xyzCol = 1:3, timeCol = c(), sf = sf, impute = FALSE)
         data = as.matrix(data)
-      }
+      } 
       LD = nrow(data)
       #store data that could not be used for this block, but will be added to next block
       use = (floor(LD / (ws*sf))) * (ws*sf) #number of datapoint to use
@@ -205,8 +209,8 @@ g.calibrate = function(datafile, params_rawdata = c(),
             Gx = data[,1]; Gy = data[,2]; Gz = data[,3]
             use.temp = FALSE
           } else if (mon == 2 & dformat == 1) { #GENEActiv bin
-            Gx = data[,2]; Gy = data[,3]; Gz = data[,4]; temperature = data[,7]
-            temperature = as.numeric(data[,7])
+            Gx = data[,2]; Gy = data[,3]; Gz = data[,4]
+            use.temp = TRUE
           } else if (mon == 5) { # Movisense
             Gx = data[,1]; Gy = data[,2]; Gz = data[,3]
             use.temp = TRUE
@@ -229,9 +233,15 @@ g.calibrate = function(datafile, params_rawdata = c(),
           
           if (mon == 2 | (mon == 4 & dformat == 4) | (mon == 0 & use.temp == TRUE)) {
             if (mon == 2) { # GENEActiv
-              temperaturecolumn = 7
+              if ("temperature" %in% colnames(data)) {
+                temperaturecolumn = which(colnames(data) == "temperature") #GGIRread
+              } else {
+                temperaturecolumn = 7
+              }
             } else if (mon == 4 | mon == 5) { #AX | Movisense
               temperaturecolumn = 5
+            } else if (mon == 0) {
+              temperaturecolumn = params_rawdata[["rmc.col.temp"]]
             }
             temperature = as.numeric(data[,temperaturecolumn])
           } else if (mon == 1 | mon == 3) { # GENEA or Actigraph
@@ -249,7 +259,7 @@ g.calibrate = function(datafile, params_rawdata = c(),
             if (length(which(is.na(mean(as.numeric(data[1:10,temperaturecolumn]))) == T)) > 0) {
               cat("\ntemperature is NA\n")
               use.temp = FALSE
-            } else if (length(which(mean(as.numeric(data[1:10,temperaturecolumn])) > 40)) > 0) {
+            } else if (length(which(mean(as.numeric(data[1:10,temperaturecolumn])) > 120)) > 0) {
               cat("\ntemperature is too high\n")
               use.temp = FALSE
             }
@@ -331,7 +341,9 @@ g.calibrate = function(datafile, params_rawdata = c(),
                            abs(as.numeric(meta_temp[,2])) < 2 & abs(as.numeric(meta_temp[,3])) < 2 &
                            abs(as.numeric(meta_temp[,4])) < 2) #the latter three are to reduce chance of including clipping periods
       meta_temp = meta_temp[nomovement,]
-      rm(nomovement)
+      dup = which(rowSums(meta_temp[1:(nrow(meta_temp) - 1), 2:7] == meta_temp[2:nrow(meta_temp), 2:7]) == 3) # remove duplicated values
+      if (length(dup) > 0) meta_temp = meta_temp[-dup,]
+      rm(nomovement, dup)
       if (min(dim(meta_temp)) > 1) {
         meta_temp = meta_temp[(is.na(meta_temp[,4]) == F & is.na(meta_temp[,1]) == F),]
         npoints = nrow(meta_temp)
@@ -464,7 +476,7 @@ g.calibrate = function(datafile, params_rawdata = c(),
       QC = "recalibration not done because recalibration does not decrease error"
     }
   }
-  if (length(ncol(meta_temp)) != 0) {
+  if (all(dim(meta_temp)) != 0) {  # change 2022-08-18 to handle when filetooshort = TRUE (7 columns, empty rows)
     spheredata = data.frame(A = meta_temp, stringsAsFactors = TRUE)
     if (use.temp == TRUE) {
       names(spheredata) = c("Euclidean Norm","meanx","meany","meanz","sdx","sdy","sdz","temperature")
