@@ -8,7 +8,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
   # description: function called by g.shell.GGIR
   # aimed to merge the milestone output from g.part2, g.part3, and g.part4
   # in order to create a merged report of both physical activity and sleep
-  
   #----------------------------------------------------------
   # Extract and check parameters
   input = list(...)
@@ -29,7 +28,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
   params_cleaning = params$params_cleaning
   params_output = params$params_output
   params_general = params$params_general
-  
   #======================================================================
   # create new folder (if not existent) for storing milestone data
   ms5.out = "/meta/ms5.out"
@@ -64,7 +62,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
   #======================================================================
   # compile lists of milestone data filenames
   fnames.ms3 = sort(dir(paste(metadatadir, "/meta/ms3.out", sep = "")))
-  
+
   fnames.ms5 = sort(dir(paste(metadatadir, "/meta/ms5.out", sep = "")))
   # path to sleeplog milestonedata, if it exists:
   sleeplogRDA = paste(metadatadir, "/meta/sleeplog.RData", sep = "")
@@ -92,7 +90,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
   if (params_output[["save_ms5raw_format"]] != "RData" & params_output[["save_ms5raw_format"]] != "csv") {
     params_output[["save_ms5raw_format"]] = "csv"# specify as csv if user does not clearly specify format
   }
-  
   #--------------------------------
   # get full file path and folder name if requested by end-user and keep this for storage in output
   if (params_output[["storefolderstructure"]] == TRUE) {
@@ -118,7 +115,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
     fnames.ms1 = sort(dir(paste(metadatadir, "/meta/basic", sep = "")))
     fnames.ms2 = sort(dir(paste(metadatadir, "/meta/ms2.out", sep = "")))
     fnames.ms4 = sort(dir(paste(metadatadir, "/meta/ms4.out", sep = "")))
-    
     nfeatures = 500
     ws3 = params_general[["windowsizes"]][1]
     ds_names = rep("",nfeatures)
@@ -127,7 +123,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
     if (length(params_cleaning[["data_cleaning_file"]]) > 0) {
       if (file.exists(params_cleaning[["data_cleaning_file"]])) DaCleanFile = read.csv(params_cleaning[["data_cleaning_file"]])
     }
-    
     if (length(ffdone) > 0) {
       if (length(which(ffdone == fnames.ms3[i])) > 0) {
         skip = 1 #skip this file because it was analysed before")
@@ -180,7 +175,8 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
         load(paste0(metadatadir, "/meta/ms3.out/", fnames.ms3[i]))
         # extract key variables from the mile-stone data: time, acceleration and elevation angle
         # note that this is imputed ACCELERATION because we use this for describing behaviour:
-        ts = data.frame(time = IMP$metashort[,1], ACC = IMP$metashort[,params_general[["acc.metric"]]] * 1000,
+        scale = ifelse(test = grepl("^Brond|^Neishabouri|^ZC", params_general[["acc.metric"]]), yes = 1, no = 1000)
+        ts = data.frame(time = IMP$metashort[,1], ACC = IMP$metashort[,params_general[["acc.metric"]]] * scale,
                         guider = rep("unknown", nrow(IMP$metashort)),
                         angle = as.numeric(as.matrix(IMP$metashort[,which(names(IMP$metashort) == "anglez")])) )
         Nts = nrow(ts)
@@ -344,7 +340,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                                                   possible_nap_dur = params_sleep[["possible_nap_dur"]],
                                                   nap_model = params_sleep[["nap_model"]],
                                                   HASIB.algo = params_sleep[["HASIB.algo"]])
-              
               # store in ts object, such that it is exported in as time series
               ts$nap1_nonwear2 = 0
               # napsindices = which(naps_nonwear$probability_nap == 1)
@@ -485,14 +480,14 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                           # Add to dsummary output matrix
                           if (skiponset == FALSE) {
                             dsummary[di,fi] = onset
-                            dsummary[di,fi + 1] = as.character(strftime(as.character(time_POSIX[onseti]), tz = params_general[["desiredtz"]], format = "%H:%M:%S"))
+                            dsummary[di,fi + 1] = as.character(strftime(format(time_POSIX[onseti]), tz = params_general[["desiredtz"]], format = "%H:%M:%S"))
                           } else {
                             dsummary[di,fi:(fi + 1)] = rep(NA, 2)
                           }
                           ds_names[fi:(fi + 1)] = c("sleeponset", "sleeponset_ts");      fi = fi + 2
                           if (skipwake == FALSE) {
                             dsummary[di,fi] = wake
-                            dsummary[di,fi + 1] = as.character(strftime(as.character(time_POSIX[wakei]), tz = params_general[["desiredtz"]], format = "%H:%M:%S"))
+                            dsummary[di,fi + 1] = as.character(strftime(format(time_POSIX[wakei]), tz = params_general[["desiredtz"]], format = "%H:%M:%S"))
                           } else {
                             dsummary[di,fi:(fi + 1)] = rep(NA, 2)
                           }
@@ -595,7 +590,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                           dsummary[di,fi] = length(which(ts$sibdetection[sse] == 1 &
                                                            ts$diur[sse] == 1)) / length(which(ts$diur[sse] == 1))
                           ds_names[fi] = "sleep_efficiency";      fi = fi + 1
-                          
                           #===============================================
                           # NAPS (estimation)
                           if (params_output[["do.sibreport"]] == TRUE & "nap1_nonwear2" %in% colnames(ts) & length(params_sleep[["nap_model"]]) > 0) {
@@ -659,7 +653,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                                 e2 = (hri + (wini * (60/reso))) * reso * (60/ws3new)
                                 if (e2 > length(sse)) e2 = length(sse)
                                 ACCrunwin[(hri + 1), 1] = mean(ts$ACC[sse[e1:e2]])
-                                TIMErunwin[(hri + 1), 1] = as.character(ts$time[sse[e1]])
+                                TIMErunwin[(hri + 1), 1] = format(ts$time[sse[e1]])
                               }
                               ACCrunwin = ACCrunwin[is.na(ACCrunwin) == F]
                               TIMErunwin = TIMErunwin[is.na(ACCrunwin) == F]
@@ -671,7 +665,7 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                                 M5VALUE = max(ACCrunwin)
                                 if (lightpeak_available == TRUE) {
                                   if (length(unlist(strsplit(M5HOUR, " "))) == 1) M5HOUR = paste0(M5HOUR, " 00:00:00")
-                                  startM5 = which(as.character(ts$time) == M5HOUR)
+                                  startM5 = which(format(ts$time) == M5HOUR)
                                   M5_mean_peakLUX = round(mean(ts$lightpeak[startM5[1]:(startM5[1] + (wini*60*(60/ws3new)))], na.rm = TRUE), digits = 1)
                                   M5_max_peakLUX = round(max(ts$lightpeak[startM5[1]:(startM5[1] + (wini*60*(60/ws3new)))], na.rm = TRUE), digits = 1)
                                 }
@@ -707,8 +701,8 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                             if (ignore == FALSE) {
                               # Add also numeric time
                               if (is.ISO8601(L5HOUR)) { # only do this for ISO8601 format
-                                L5HOUR = as.character(iso8601chartime2POSIX(L5HOUR, tz = params_general[["desiredtz"]]))
-                                M5HOUR = as.character(iso8601chartime2POSIX(M5HOUR, tz = params_general[["desiredtz"]]))
+                                L5HOUR = format(iso8601chartime2POSIX(L5HOUR, tz = params_general[["desiredtz"]]))
+                                M5HOUR = format(iso8601chartime2POSIX(M5HOUR, tz = params_general[["desiredtz"]]))
                               }
                               if (length(unlist(strsplit(L5HOUR," "))) == 1) L5HOUR = paste0(L5HOUR," 00:00:00") #added because on some OS timestamps are deleted for midnight
                               if (length(unlist(strsplit(M5HOUR," "))) == 1) M5HOUR = paste0(M5HOUR," 00:00:00")
@@ -879,13 +873,9 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                     }
                     # I moved this bit of code to the end, because we want guider to be included (VvH April 2020)
                     rawlevels_fname =  paste0(metadatadir, ms5.outraw, "/", TRLi, "_", TRMi, "_", TRVi, "/",
-                                              gsub(pattern = "[.]|rdata|csv|cwa|gt3x|bin", 
+                                              gsub(pattern = "[.]|rdata|csv|cwa|gt3x|bin",
                                                    replacement = "", x = tolower(fnames.ms3[i])),
                                               "_", j, ".", params_output[["save_ms5raw_format"]])
-                    
-                    
-                    
-                    
                     # save time series to csv files
                     if (params_output[["do.sibreport"]] == TRUE & length(params_sleep[["nap_model"]]) > 0) {
                       napNonwear_col = "nap1_nonwear2"
@@ -960,7 +950,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
             emptycols = emptycols[which(emptycols %in% FRAG_variables_indices == FALSE)]
             if (length(emptycols) > 0) output = output[,-emptycols]
           }
-       
           if (length(output) > 0) {
             if (nrow(output) > 0) {
               save(output, tail_expansion_log, file = paste(metadatadir,
@@ -972,7 +961,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
       }
     }
   }
-  
   #======================================================================
   # loop through milestone data-files or filenames stored in output of g.part2 and g.part4
   # setup parallel backend to use many processors
@@ -1030,7 +1018,6 @@ g.part5 = function(datadir = c(), metadatadir = c(), f0=c(), f1=c(),
                                      })
                                      return(tryCatchResult)
                                    }
-    
     on.exit(parallel::stopCluster(cl))
     for (oli in 1:length(output_list)) { # logged error and warning messages
       if (is.null(unlist(output_list[oli])) == FALSE) {
