@@ -41,8 +41,10 @@ load_params = function(group = c("sleep", "metrics", "rawdata",
                           do.hfx = FALSE, do.hfy = FALSE, do.hfz = FALSE,
                           do.bfx = FALSE, do.bfy = FALSE, do.bfz = FALSE,
                           do.brondcounts = FALSE,
+                          do.neishabouricounts = FALSE,
                           hb = 15, lb = 0.2, n = 4,
-                          zc.lb = 0.25, zc.hb = 3, zc.sb = 0.01, zc.order = 2, zc.scale = 1)
+                          zc.lb = 0.25, zc.hb = 3, zc.sb = 0.01, zc.order = 2, zc.scale = 1,
+                          actilife_LFE = FALSE)
   }
   if ("rawdata" %in% group) {
     params_rawdata = list(
