@@ -44,11 +44,10 @@ test_that("g.getbout produces expected output", {
   set.seed(300)
   bm4 = g.getbout(x=round(runif(1000,0.4,1)),boutduration = 120,boutcriter=0.9,
                   closedbout=FALSE,bout.metric=4,ws3=5)
-  bm4Ex = c( rep(0,120), rep(1,124), rep(0,756))
-  bm4Eboutcount = c(rep(0,120), rep(1,124), rep(0,756))
-  
-  expect_that(sum(bm4$x),equals(124))
-  expect_that(sum(bm4$boutcount),equals(124))
+  bm4Ex = c(rep(0,42), rep(1,285), rep(0,673))
+  bm4Eboutcount = c(rep(0,42), rep(1,285), rep(0,673))
+  expect_that(sum(bm4$x),equals(285))
+  expect_that(sum(bm4$boutcount),equals(285))
   expect_that(bm4$x,equals(bm4Ex))
   expect_that(bm4$boutcount,equals(bm4Eboutcount))
   
@@ -60,5 +59,33 @@ test_that("g.getbout produces expected output", {
   bm5Eboutcount = c(rep(0,42), rep(1,285), rep(0,673))
   expect_that(sum(bm5$x),equals(285))
   expect_that(sum(bm5$boutcount),equals(285))
- 
+  
+  # Metric 6
+  set.seed(300)
+  xtest = c(rep(0,15), rep(1,6), 0, rep(1,10),rep(0,20))
+  bm6 = g.getbout(x=xtest,boutduration = 10, boutcriter=1,
+                  closedbout=FALSE,bout.metric=6,ws3=60)
+  bm6Ex = c(rep(0,27), rep(1,10), rep(0,20))
+  bm6Eboutcount = c(rep(0,27), rep(1,10), rep(0,20))
+  expect_that(sum(bm6$x),equals(10))
+  # Metric 6 - ability to detect even length bout
+  set.seed(300)
+  xtest = x = c(rep(1, 4), rep(0, 3), rep(1, 6),rep(0, 3), rep(1, 10), 0 , rep(1, 9))
+  bm6b = g.getbout(x=xtest,boutduration = 10, boutcriter=1,
+                  closedbout=FALSE,bout.metric=6,ws3=60)
+  expect_that(sum(bm6b$x),equals(10))
+  expect_that(sum(bm6b$boutcount),equals(10))
+  
+  # Metric 6 - ability to detect odd length bouts
+  set.seed(300)
+  xtest = x = c(rep(0, 20), rep(1, 9), rep(0, 20))
+  bm6c = g.getbout(x=xtest,boutduration =9, boutcriter=1,
+                   closedbout=FALSE,bout.metric=6,ws3=60)
+  expect_that(sum(bm6c$x),equals(9))
+  # Metric 6 - ability to detect bouts with grace periods
+  xtest = c(rep(0,15), rep(1,6), 0, rep(1,10),rep(0,20))
+  bm6 = g.getbout(x=xtest,boutduration = 10, boutcriter=0.9,
+                  closedbout=FALSE,bout.metric=6,ws3=60)
+  expect_that(sum(bm6$x),equals(17))
+  
 })
\ No newline at end of file
