@@ -192,17 +192,17 @@ test_that("read.myacc.csv can read a variety of csv file formats", {
                       rmc.headername.sf = "sample_rate",
                       rmc.headername.sn = "serial_number",
                       rmc.headername.recordingid = "ID", 
-                      rmc.bit = "bit", rmc.dynamic_range = "dynamic_range",
+                      rmc.bitrate = "bit", rmc.dynamic_range = "dynamic_range",
                       rmc.header.structure = c(), rmc.check4timegaps = TRUE)
   
-  expect_that(round(mean(D7$data[,2]), digits = 3), equals(0.955))
-  expect_that(round(mean(D7$data[,3]), digits = 2), equals(0.27))
-  expect_that(round(mean(D7$data[,4]), digits = 2), equals(-0.35))
-  expect_that(round(mean(D7$data[,5]), digits = 1), equals(20))
-  expect_that(round(D7$data[2,2], digits = 3), equals(5.578))
-  expect_that(ncol(D7$data), equals(5))
-  expect_that(nrow(D7$header), equals(5))
-  expect_that(ncol(D7$header), equals(1))
+  expect_equal(mean(D7$data[,2]), 0.761, tolerance = 3)
+  expect_equal(mean(D7$data[,3]), -0.62, tolerance = 2)
+  expect_equal(mean(D7$data[,4]), -0.36, tolerance = 1)
+  expect_equal(mean(D7$data[,5]), 20.1, tolerance = 1)
+  expect_equal(D7$data[2,2], 5.578, tolerance  = 3)
+  expect_equal(ncol(D7$data), 5)
+  expect_equal(nrow(D7$header),5)
+  expect_equal(ncol(D7$header), 1)
     
   for (i in 1:length(testfile)) {
     expect_true(file.exists(testfile[i]))
